@@ -33,10 +33,10 @@ from django.utils.translation import ugettext as _
 from lino import dd
 from lino import mixins
 from lino.utils import i2d, Cycler
+from lino.mixins.beid import BeIdCardTypes
 from lino.utils.instantiator import Instantiator
 from lino.core.dbutils import resolve_model
-from north.dbutils import babel_values
-from north.dbutils import babel_values as babelkw
+from north.dbutils import babelkw
 from north.dbutils import field2kw
 from lino.utils.restify import restify
 from lino.utils import dblogger
@@ -49,14 +49,20 @@ from lino.modlib.cal.utils import DurationUnits
 #~ from django.contrib.auth import models as auth
 #~ from lino.modlib.users import models as auth
 #~ from lino.modlib.contacts.utils import Gender
-from lino_welfare.modlib.jobs import models as jobs
-from lino.modlib.contacts import models as contacts
-from lino.modlib.countries import models as countries
-from lino_welfare.modlib.pcsw import models as pcsw
-from lino_welfare.modlib.isip import models as isip
+#~ from lino_welfare.modlib.jobs import models as jobs
+#~ from lino.modlib.contacts import models as contacts
+#~ from lino.modlib.countries import models as countries
+#~ from lino_welfare.modlib.pcsw import models as pcsw
+#~ from lino_welfare.modlib.isip import models as isip
 
+isip = dd.resolve_app('isip')
+jobs = dd.resolve_app('jobs')
+pcsw = dd.resolve_app('pcsw')
 contacts = dd.resolve_app('contacts')
 users = dd.resolve_app('users')
+countries = dd.resolve_app('countries')
+reception = dd.resolve_app('reception')
+cal = dd.resolve_app('cal')
 
 Company = dd.resolve_model('contacts.Company')
 
@@ -180,202 +186,6 @@ def unused_coachings(p,type,coach1,coach2,coached_from,coached_until=None):
 
 def objects():
     
-    guest_role = Instantiator('cal.GuestRole').build
-    obj = guest_role(email_template="Visitor.eml.html",**babel_values('name',
-          de="Besucher",
-          fr="Visiteur",
-          en="Visitor",
-          et="Külaline",
-          ))
-    yield obj
-    settings.SITE.site_config.update(client_guestrole=obj)
-    
-    obj = guest_role(**babel_values('name',
-          de="Kollege",
-          fr="Collègue",
-          en="Colleague",
-          et="Kolleeg",
-          ))
-    yield obj
-    settings.SITE.site_config.update(team_guestrole=obj)
-    
-    yield guest_role(**babel_values('name',
-          de=u"Vorsitzender",
-          fr=u"Président",
-          en=u"Presider",
-          et=u"Eesistuja",
-          ))
-    yield guest_role(**babel_values('name',
-          de=u"Protokollführer",
-          fr=u"Greffier",
-          en=u"Reporter",
-          et=u"Sekretär",
-          ))
-    
-    
-    calendar = Instantiator('cal.Calendar').build
-    obj = calendar(color=20,invite_client=True,**babel_values('name',
-          de="Klientengespräche intern",
-          fr="Rencontres internes avec client",
-          en="Internal meetings with client",
-          ))
-    yield obj
-    settings.SITE.site_config.update(client_calender=obj)
-    
-    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.months).build
-    yield exam_policy(1,calendar=obj,start_time="9:00",**babel_values('name',en='every month',de=u'monatlich',fr=u"mensuel"))
-    yield exam_policy(2,calendar=obj,start_time="9:00",**babel_values('name',en='every 2 months',de=u'zweimonatlich',fr=u"bimensuel"))
-    yield exam_policy(3,calendar=obj,start_time="9:00",**babel_values('name',en='every 3 months',de=u'alle 3 Monate',fr=u"tous les 3 mois"))
-    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.weeks).build
-    yield exam_policy(2,calendar=obj,start_time="9:00",**babel_values('name',en='every 2 weeks',de=u'zweiwöchentlich',fr=u"hebdomadaire"))
-    exam_policy = Instantiator('isip.ExamPolicy').build
-    yield exam_policy(**babel_values('name',en='other',de="andere",fr="autre"))
-        
-    
-        
-    yield calendar(color=1,invite_client=True,**babel_values('name',
-          de=u"Klientengespräche extern",
-          fr=u"Rencontres client externes",
-          en=u"External meetings with client",
-          ))
-    
-    yield calendar(color=4,**babel_values('name',
-          de=u"Versammlung intern",
-          fr=u"Réunions internes",
-          en=u"Internal meetings",
-          ))
-    
-    yield calendar(color=8,**babel_values('name',
-          de=u"Versammlung extern",
-          fr=u"Réunions externes",
-          en=u"External meetings",
-          ))
-          
-    yield calendar(color=12,
-        #~ invite_team_members=True,email_template='Team.eml.html',
-        email_template='Team.eml.html',
-        **babel_values('name',
-          de=u"Team-Besprechungen",
-          fr=u"Coordinations en équipe",
-          en=u"Team Meetings",
-          ))
-    #~ yield etype(**babel_values('name',
-          #~ de=u"Erstgespräch",
-          #~ fr=u"Première rencontre",
-          #~ en=u"First meeting",
-          #~ ))
-    #~ yield etype(**babel_values('name',
-          #~ de=u"Auswertungsgespräch",
-          #~ fr=u"Évaluation",
-          #~ en=u"Evaluation",
-          #~ ))
-    
-  
-    sector = Instantiator(jobs.Sector).build
-    for ln in SECTORS_LIST.splitlines():
-        if ln:
-            a = ln.split('|')
-            if len(a) == 3:
-                kw = dict(en=a[0],fr=a[1],de=a[2])
-                yield sector(**babel_values('name',**kw))
-                
-    horeca = jobs.Sector.objects.get(pk=5)
-    function = Instantiator(jobs.Function,sector=horeca).build
-    yield function(**babel_values('name',
-          de=u"Kellner",
-          fr=u'Serveur',
-          en=u'Waiter',
-          ))
-    yield function(**babel_values('name',
-          de=u"Koch",
-          fr=u'Cuisinier',
-          en=u'Cook',
-          ))
-    yield function(**babel_values('name',
-          de=u"Küchenassistent",
-          fr=u'Aide Cuisinier',
-          en=u'Cook assistant',
-          ))
-    yield function(**babel_values('name',
-          de=u"Tellerwäscher",
-          fr=u'Plongeur',
-          en=u'Dishwasher',
-          ))
-
-    contractType = Instantiator(jobs.ContractType,"ref",
-        exam_policy=3,
-        build_method='appypdf',
-        template=u'art60-7.odt').build
-    #~ yield contractType('art60-7a',
-      #~ **babel_values('name',
-          #~ de=u"Konvention Art.60§7 Sozialökonomie",
-          #~ fr=u'Convention art.60§7 économie sociale',
-          #~ en=u'Convention art.60§7 social economy',
-          #~ ))
-    yield contractType('art60-7a',
-      **babel_values('name',
-          de=u"Sozialökonomie",
-          fr=u'économie sociale',
-          en=u'social economy',
-          ))
-    yield contractType('art60-7b',
-      **babel_values('name',
-          de=u"Sozialökonomie - majoré",
-          fr=u'économie sociale - majoré',
-          en=u'social economy - increased',
-          ))
-    yield contractType('art60-7c',
-      **babel_values('name',
-          de=u"mit Rückerstattung",
-          fr=u'avec remboursement',
-          en=u'social economy with refund',
-          ))
-    yield contractType('art60-7d',
-      **babel_values('name',
-          de=u"mit Rückerstattung Schule",
-          fr=u'avec remboursement école',
-          en=u'social economy school',
-          ))
-    yield contractType('art60-7e',
-      **babel_values('name',
-          de=u"Stadt Eupen",
-          fr=u"ville d'Eupen",
-          en=u'town',
-          ))
-    
-    contractType = Instantiator(isip.ContractType,"ref",
-      exam_policy=1,
-      build_method='appypdf',template=u'vse.odt').build
-    yield contractType("vsea",needs_study_type=True,**babel_values('name',
-          de=u"VSE Ausbildung",
-          fr=u"VSE Ausbildung",
-          en=u"VSE Ausbildung",
-          ))
-    yield contractType("vseb",**babel_values('name',
-          de=u"VSE Arbeitssuche",
-          fr=u"VSE Arbeitssuche",
-          en=u"VSE Arbeitssuche",
-          ))
-    yield contractType("vsec",**babel_values('name',
-          de=u"VSE Lehre",
-          fr=u"VSE Lehre",
-          en=u"VSE Lehre",
-          ))
-    yield contractType("vsed",needs_study_type=True,**babel_values('name',
-          de=u"VSE Vollzeitstudium",
-          fr=u"VSE Vollzeitstudium",
-          en=u"VSE Vollzeitstudium",
-          ))
-    yield contractType("vsee",**babel_values('name',
-          de=u"VSE Sprachkurs",
-          fr=u"VSE Sprachkurs",
-          en=u"VSE Sprachkurs",
-          ))
-    #~ yield contractType(u"VSE Integration")
-    #~ yield contractType(u"VSE Cardijn")
-    #~ yield contractType(u"VSE Work & Job")
-    
-  
     ClientContactType = resolve_model('pcsw.ClientContactType')
   
     Person = resolve_model('contacts.Person')
@@ -392,10 +202,6 @@ def objects():
     #~ Country = resolve_model('countries.Country')
     Client = resolve_model('pcsw.Client')
     
-    rt = RoleType.objects.get(pk=4) # It manager
-    rt.use_in_contracts = False
-    rt.save()
-
     person = Instantiator(Person).build
     client = Instantiator(Client).build
     company = Instantiator(Company).build
@@ -410,10 +216,7 @@ def objects():
     StudyType = resolve_model('isip.StudyType')
     #~ Country = resolve_model('countries.Country')
     Property = resolve_model('properties.Property')
-  
     
-    #~ country = Instantiator('countries.Country',"isocode name").build
-    #~ yield country('SUHH',"Soviet Union")
     
     eupen = City.objects.get(name__exact='Eupen')
     #~ stvith = City.objects.get(zip_code__exact='4780')
@@ -428,6 +231,353 @@ def objects():
     ulrike = Person.objects.get(name__exact="Charlier Ulrike")
     erna = Person.objects.get(name__exact=u"Ärgerlich Erna")
     
+    
+    
+    
+    #~ ug_dsbe = users.Group(name="DSBE")
+    #~ yield ug_dsbe 
+    #~ ug_courses = users.Group(name="Courses")
+    #~ yield ug_courses
+    #~ ug_asd = users.Group(name="ASD")
+    #~ yield ug_asd 
+    #~ ug_sek = users.Group(name="Sekretariat")
+    #~ yield ug_sek 
+    #~ ug_staff = users.Group(name="Staff")
+    #~ yield ug_staff 
+    
+    #~ yield User(username='gerd',partner=gerd,profile='900')
+    
+    melanie = person(first_name="Mélanie",last_name="Mélard",
+        email=settings.SITE.demo_email, # 'melanie@example.com',
+        city=eupen,country='BE',gender=mixins.Genders.female,
+        language='fr')
+    yield melanie
+    melanie = users.User(username="melanie",partner=melanie,profile='110') 
+    yield melanie
+    
+    hubert = person(first_name=u"Hubert",last_name=u"Huppertz",
+        email=settings.SITE.demo_email, # 'hubert@example.com',
+        city=kettenis,country='BE',gender=mixins.Genders.male)
+    yield hubert
+    hubert = users.User(username="hubert",partner=hubert,profile='100') 
+    yield hubert
+    
+    alicia = person(first_name=u"Alicia",last_name=u"Allmanns",
+        email=settings.SITE.demo_email, # 'alicia@example.com',
+        city=kettenis,country='BE',gender=mixins.Genders.female,language='fr')
+    yield alicia
+    alicia = users.User(username="alicia",partner=alicia,profile='100') 
+    yield alicia
+    
+    theresia = person(first_name=u"Theresia",last_name=u"Thelen",
+        email=settings.SITE.demo_email, # 'theresia@example.com',
+        city=eupen,country='BE',gender=mixins.Genders.female)
+    yield theresia
+    theresia = users.User(username="theresia",partner=theresia,profile='210') 
+    yield theresia
+    
+    yield Authority(user=alicia,authorized=hubert)
+    yield Authority(user=alicia,authorized=melanie)
+    yield Authority(user=hubert,authorized=melanie)
+    
+    #~ yield users.Membership(user=alicia,group=ug_dsbe)
+    #~ yield users.Membership(user=hubert,group=ug_dsbe)
+    #~ yield users.Membership(user=melanie,group=ug_dsbe)
+    #~ yield users.Membership(user=melanie,group=ug_courses)
+    #~ yield users.Membership(user=melanie,group=ug_sek)
+    
+    caroline = users.User(username="caroline",
+        first_name="Caroline",last_name="Carnol",
+        profile='200') # UserProfiles.caroline)
+    yield caroline
+    #~ yield users.Membership(user=caroline,group=ug_asd)
+    
+    obj = person(first_name="Judith",last_name="Jousten",
+        email=settings.SITE.demo_email, 
+        city=eupen,country='BE',gender=mixins.Genders.female)
+    yield obj
+    judith = users.User(username="judith",partner=obj,profile='400') 
+    yield judith
+    
+    
+    # id must be 1 (see isip.ContactBase.person_changed
+    yield pcsw.CoachingType(id=isip.COACHINGTYPE_ASD,**babelkw('name',
+        de="ASD (Allgemeiner Sozialdienst)",
+        nl="ASD (Algemene Sociale Dienst)",
+        fr="SSG (Service social général)",
+        en="GSS (General Social Service)",
+        )) 
+    
+    caroline.coaching_type_id = isip.COACHINGTYPE_ASD
+    caroline.save()
+    judith.coaching_type_id = isip.COACHINGTYPE_ASD
+    judith.save()
+    
+    DSBE = pcsw.CoachingType(id=isip.COACHINGTYPE_DSBE,**babelkw('name',
+        de="DSBE (Dienst für Sozial-Berufliche Eingliederung)",
+        fr="Service intégration",
+        en="Integration service",
+        )) 
+    
+    #~ DSBE = pcsw.CoachingType(name="DSBE")
+    yield DSBE
+    #~ yield pcsw.CoachingType(name="Schuldnerberatung")
+    yield pcsw.CoachingType(**babelkw('name',
+        de="Schuldnerberatung",
+        fr="Médiation de dettes",
+        en="Debts mediation",
+        )) 
+    
+    alicia.coaching_type= DSBE
+    alicia.save()
+    
+    for obj in pcsw.CoachingType.objects.all():
+        yield users.Team(**babelkw('name',**field2kw(obj,'name')))
+    
+    
+    guest_role = Instantiator('cal.GuestRole').build
+    obj = guest_role(email_template="Visitor.eml.html",**babelkw('name',
+          de="Besucher",
+          fr="Visiteur",
+          en="Visitor",
+          et="Külaline",
+          ))
+    yield obj
+    settings.SITE.site_config.update(client_guestrole=obj)
+    
+    obj = guest_role(**babelkw('name',
+          de="Kollege",
+          fr="Collègue",
+          en="Colleague",
+          et="Kolleeg",
+          ))
+    yield obj
+    settings.SITE.site_config.update(team_guestrole=obj)
+    
+    yield guest_role(**babelkw('name',
+          de=u"Vorsitzender",
+          fr=u"Président",
+          en=u"Presider",
+          et=u"Eesistuja",
+          ))
+    yield guest_role(**babelkw('name',
+          de=u"Protokollführer",
+          fr=u"Greffier",
+          en=u"Reporter",
+          et=u"Sekretär",
+          ))
+    
+    
+    note_nature = Instantiator('notes.EventType').build
+    obj = note_nature(**babelkw('name',
+          de="Bescheinigung",
+          fr="Attestation",
+          en="Attestation",
+          et="Tõend",
+          ))
+    yield obj
+    settings.SITE.site_config.update(attestation_note_nature=obj)
+    
+    
+        
+    calendar = Instantiator('cal.Calendar').build
+    client_calendar = calendar(color=20,invite_client=True,**babelkw('name',
+          de="Klientengespräche intern",
+          fr="Rencontres internes avec client",
+          en="Internal meetings with client",
+          ))
+    yield client_calendar
+    settings.SITE.site_config.update(client_calendar=client_calendar)
+    
+    obj = calendar(color=20,invite_client=False,is_appointment=False,**babelkw('name',
+          de="Visiten (ohne Termin)",
+          fr="Visites (sans rendez-vous)",
+          en="Prompt events",
+          et="Külaline",
+          ))
+    yield obj
+    settings.SITE.site_config.update(prompt_calendar=obj)
+    
+        
+    yield calendar(color=1,invite_client=False,**babelkw('name',
+          de="Klientengespräche extern",
+          fr="Rencontres client externes",
+          en="External meetings with client",
+          ))
+    
+    yield calendar(color=4,**babelkw('name',
+          de=u"Versammlung intern",
+          fr=u"Réunions internes",
+          en=u"Internal meetings",
+          ))
+    
+    yield calendar(color=8,**babelkw('name',
+          de=u"Versammlung extern",
+          fr=u"Réunions externes",
+          en=u"External meetings",
+          ))
+          
+    for obj in users.Team.objects.all():
+        yield calendar(color=12,
+            invite_team_members=obj,
+            email_template='Team.eml.html',
+            **babelkw('name',**field2kw(obj,'name')))
+          
+    #~ yield calendar(color=12,
+        #~ email_template='Team.eml.html',
+        #~ **babelkw('name',
+          #~ de=u"Team-Besprechungen",
+          #~ fr=u"Coordinations en équipe",
+          #~ en=u"Team Meetings",
+          #~ ))
+          
+    yield calendar(color=25,**babelkw('name',
+          de="Privat",
+          fr="Privé",
+          en="Private",
+          ))
+          
+          
+    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.months).build
+    yield exam_policy(1,calendar=client_calendar,start_time="9:00",**babelkw('name',en='every month',de=u'monatlich',fr=u"mensuel"))
+    yield exam_policy(2,calendar=client_calendar,start_time="9:00",**babelkw('name',en='every 2 months',de=u'zweimonatlich',fr=u"bimensuel"))
+    yield exam_policy(3,calendar=client_calendar,start_time="9:00",**babelkw('name',en='every 3 months',de=u'alle 3 Monate',fr=u"tous les 3 mois"))
+    
+    exam_policy = Instantiator('isip.ExamPolicy','every',every_unit=DurationUnits.weeks).build
+    yield exam_policy(2,calendar=client_calendar,start_time="9:00",**babelkw('name',en='every 2 weeks',de=u'zweiwöchentlich',fr=u"hebdomadaire"))
+    
+    exam_policy = Instantiator('isip.ExamPolicy').build
+    yield exam_policy(**babelkw('name',en='other',de="andere",fr="autre"))
+          
+    
+    
+          
+    #~ yield etype(**babelkw('name',
+          #~ de=u"Erstgespräch",
+          #~ fr=u"Première rencontre",
+          #~ en=u"First meeting",
+          #~ ))
+    #~ yield etype(**babelkw('name',
+          #~ de=u"Auswertungsgespräch",
+          #~ fr=u"Évaluation",
+          #~ en=u"Evaluation",
+          #~ ))
+    
+  
+    sector = Instantiator(jobs.Sector).build
+    for ln in SECTORS_LIST.splitlines():
+        if ln:
+            a = ln.split('|')
+            if len(a) == 3:
+                kw = dict(en=a[0],fr=a[1],de=a[2])
+                yield sector(**babelkw('name',**kw))
+                
+    horeca = jobs.Sector.objects.get(pk=5)
+    function = Instantiator(jobs.Function,sector=horeca).build
+    yield function(**babelkw('name',
+          de=u"Kellner",
+          fr=u'Serveur',
+          en=u'Waiter',
+          ))
+    yield function(**babelkw('name',
+          de=u"Koch",
+          fr=u'Cuisinier',
+          en=u'Cook',
+          ))
+    yield function(**babelkw('name',
+          de=u"Küchenassistent",
+          fr=u'Aide Cuisinier',
+          en=u'Cook assistant',
+          ))
+    yield function(**babelkw('name',
+          de=u"Tellerwäscher",
+          fr=u'Plongeur',
+          en=u'Dishwasher',
+          ))
+
+    contractType = Instantiator(jobs.ContractType,"ref",
+        exam_policy=3,
+        build_method='appypdf',
+        template=u'art60-7.odt').build
+    #~ yield contractType('art60-7a',
+      #~ **babelkw('name',
+          #~ de=u"Konvention Art.60§7 Sozialökonomie",
+          #~ fr=u'Convention art.60§7 économie sociale',
+          #~ en=u'Convention art.60§7 social economy',
+          #~ ))
+    yield contractType('art60-7a',
+      **babelkw('name',
+          de=u"Sozialökonomie",
+          fr=u'économie sociale',
+          en=u'social economy',
+          ))
+    yield contractType('art60-7b',
+      **babelkw('name',
+          de=u"Sozialökonomie - majoré",
+          fr=u'économie sociale - majoré',
+          en=u'social economy - increased',
+          ))
+    yield contractType('art60-7c',
+      **babelkw('name',
+          de=u"mit Rückerstattung",
+          fr=u'avec remboursement',
+          en=u'social economy with refund',
+          ))
+    yield contractType('art60-7d',
+      **babelkw('name',
+          de=u"mit Rückerstattung Schule",
+          fr=u'avec remboursement école',
+          en=u'social economy school',
+          ))
+    yield contractType('art60-7e',
+      **babelkw('name',
+          de=u"Stadt Eupen",
+          fr=u"ville d'Eupen",
+          en=u'town',
+          ))
+    
+    contractType = Instantiator(isip.ContractType,"ref",
+      exam_policy=1,
+      build_method='appypdf',template=u'vse.odt').build
+    yield contractType("vsea",needs_study_type=True,**babelkw('name',
+          de=u"VSE Ausbildung",
+          fr=u"VSE Ausbildung",
+          en=u"VSE Ausbildung",
+          ))
+    yield contractType("vseb",**babelkw('name',
+          de=u"VSE Arbeitssuche",
+          fr=u"VSE Arbeitssuche",
+          en=u"VSE Arbeitssuche",
+          ))
+    yield contractType("vsec",**babelkw('name',
+          de=u"VSE Lehre",
+          fr=u"VSE Lehre",
+          en=u"VSE Lehre",
+          ))
+    yield contractType("vsed",needs_study_type=True,**babelkw('name',
+          de=u"VSE Vollzeitstudium",
+          fr=u"VSE Vollzeitstudium",
+          en=u"VSE Vollzeitstudium",
+          ))
+    yield contractType("vsee",**babelkw('name',
+          de=u"VSE Sprachkurs",
+          fr=u"VSE Sprachkurs",
+          en=u"VSE Sprachkurs",
+          ))
+    #~ yield contractType(u"VSE Integration")
+    #~ yield contractType(u"VSE Cardijn")
+    #~ yield contractType(u"VSE Work & Job")
+    
+  
+  
+    rt = RoleType.objects.get(pk=4) # It manager
+    rt.use_in_contracts = False
+    rt.save()
+
+    
+    #~ country = Instantiator('countries.Country',"isocode name").build
+    #~ yield country('SUHH',"Soviet Union")
+    
     #~ cpas = company(name=u"ÖSHZ Eupen",city=eupen,country=belgium)
     cpas = company(name=u"ÖSHZ Kettenis",city=kettenis,country=belgium)
     yield cpas
@@ -480,7 +630,7 @@ def objects():
     yield company(name=u"Baguette Stéphanie",street=u'Gospertstraße',street_no=24,**kw)
     
     
-    cct = ClientContactType(**babel_values('name',
+    cct = ClientContactType(**babelkw('name',
           de="Gerichtsvollzieher",
           fr="Huissier de justice",
           en="Bailiff"
@@ -596,100 +746,8 @@ def objects():
       
     DIRECTORS = (annette,hans,andreas,bernard)
     
-    #~ ug_dsbe = users.Group(name="DSBE")
-    #~ yield ug_dsbe 
-    #~ ug_courses = users.Group(name="Courses")
-    #~ yield ug_courses
-    #~ ug_asd = users.Group(name="ASD")
-    #~ yield ug_asd 
-    #~ ug_sek = users.Group(name="Sekretariat")
-    #~ yield ug_sek 
-    #~ ug_staff = users.Group(name="Staff")
-    #~ yield ug_staff 
-    
-    #~ yield User(username='gerd',partner=gerd,profile='900')
-    
-    melanie = person(first_name="Mélanie",last_name="Mélard",
-        email=settings.SITE.demo_email, # 'melanie@example.com',
-        city=eupen,country='BE',gender=mixins.Genders.female,
-        language='fr')
-    yield melanie
-    melanie = users.User(username="melanie",partner=melanie,profile='110') 
-    yield melanie
-    
-    hubert = person(first_name=u"Hubert",last_name=u"Huppertz",
-        email=settings.SITE.demo_email, # 'hubert@example.com',
-        city=eupen,country='BE',gender=mixins.Genders.male)
-    yield hubert
-    hubert = users.User(username="hubert",partner=hubert,profile='100') 
-    yield hubert
-    
-    alicia = person(first_name=u"Alicia",last_name=u"Allmanns",
-        email=settings.SITE.demo_email, # 'alicia@example.com',
-        city=eupen,country='BE',gender=mixins.Genders.female,language='fr')
-    yield alicia
-    alicia = users.User(username="alicia",partner=alicia,profile='100') 
-    yield alicia
-    
-    theresia = person(first_name=u"Theresia",last_name=u"Thelen",
-        email=settings.SITE.demo_email, # 'theresia@example.com',
-        city=eupen,country='BE',gender=mixins.Genders.female,language='de')
-    yield theresia
-    theresia = users.User(username="theresia",partner=theresia,profile='210') 
-    yield theresia
-    
-    yield Authority(user=alicia,authorized=hubert)
-    yield Authority(user=alicia,authorized=melanie)
-    yield Authority(user=hubert,authorized=melanie)
-    
-    #~ yield users.Membership(user=alicia,group=ug_dsbe)
-    #~ yield users.Membership(user=hubert,group=ug_dsbe)
-    #~ yield users.Membership(user=melanie,group=ug_dsbe)
-    #~ yield users.Membership(user=melanie,group=ug_courses)
-    #~ yield users.Membership(user=melanie,group=ug_sek)
-    
-    caroline = users.User(username="caroline",
-        first_name="Caroline",last_name="Carnol",
-        profile='200') # UserProfiles.caroline)
-    yield caroline
-    #~ yield users.Membership(user=caroline,group=ug_asd)
-    
-    # id must be 1 (see isip.ContactBase.person_changed
-    yield pcsw.CoachingType(id=isip.COACHINGTYPE_ASD,**babel_values('name',
-        de="ASD (Allgemeiner Sozialdienst)",
-        nl="ASD (Algemene Sociale Dienst)",
-        fr="SSG (Service social général)",
-        en="GSS (General Social Service)",
-        )) 
-    
-    #~ caroline = users.User.objects.get(username="caroline")
-    caroline.coaching_type_id = isip.COACHINGTYPE_ASD
-    caroline.save()
-    
-    DSBE = pcsw.CoachingType(id=isip.COACHINGTYPE_DSBE,**babel_values('name',
-        de="DSBE (Dienst für Sozial-Berufliche Eingliederung)",
-        fr="Service intégration",
-        en="Integration service",
-        )) 
-    
-    #~ DSBE = pcsw.CoachingType(name="DSBE")
-    yield DSBE
-    #~ yield pcsw.CoachingType(name="Schuldnerberatung")
-    yield pcsw.CoachingType(**babel_values('name',
-        de="Schuldnerberatung",
-        fr="Médiation de dettes",
-        en="Debts mediation",
-        )) 
-    
-    alicia.coaching_type= DSBE
-    alicia.save()
-    
-    for obj in pcsw.CoachingType.objects.all():
-        yield users.Team(**babelkw('name',**field2kw(obj,'name')))
-    
-    
     #~ USERS = Cycler(root,melanie,hubert,alicia)
-    AGENTS = Cycler(melanie,hubert,alicia)
+    AGENTS = Cycler(melanie,hubert,alicia,judith)
     COACHINGTYPES = Cycler(pcsw.CoachingType.objects.all())
     
     #~ CLIENTS = Cycler(andreas,annette,hans,ulrike,erna,tatjana)
@@ -779,6 +837,22 @@ def objects():
     ly = CLIENTS.pop()
     mari = CLIENTS.pop()
     iiris = CLIENTS.pop()
+    
+    luc.card_number = '591413288107'
+    luc.card_valid_from = i2d(20110819)
+    luc.card_valid_until = i2d(20160819)
+    luc.card_issuer = "Eupen"
+    luc.card_type = BeIdCardTypes.belgian_citizen
+    luc.save()
+    
+    gerd.card_number = '123456789012'
+    gerd.card_valid_from = i2d(20120819)
+    gerd.card_valid_until = i2d(20130818)
+    gerd.card_issuer = "Eupen"
+    gerd.card_type = BeIdCardTypes.foreigner_c
+    gerd.save()
+    
+    
         
     yield study(person=luc,type=schule,content=abi,
       started='19740901',stopped='19860630')
@@ -840,9 +914,7 @@ def objects():
     
     # jobs (Art.60-7)
     
-    #~ from lino_welfare.modlib.jobs.models import Job
-    #~ CTYPES = Cycler(*[x for x in ContractType.objects.all()])
-    #~ JTYPES = Cycler(*[x for x in JobType.objects.all()])
+    CSTATES = Cycler(jobs.CandidatureStates.objects())
     JOBS_CONTRACT_TYPES = Cycler(jobs.ContractType.objects.all())
     STUDY_TYPES = Cycler(isip.StudyType.objects.all())
     JTYPES = Cycler(jobs.JobType.objects.all())
@@ -861,15 +933,74 @@ def objects():
           name=unicode(f),
           remark=REMARKS.pop(),
           sector=SECTORS.pop(),function=f)
+          
+          
     
     JOBS = Cycler(jobs.Job.objects.all())
-    CSTATES = Cycler(jobs.CandidatureStates.objects())
         
     for i in range(40):
         yield jobs.Candidature(job=JOBS.pop(),
           person=CLIENTS.pop(),
           state=CSTATES.pop(),
           date_submitted=settings.SITE.demo_date(-40+i))
+          
+          
+    # reset SECTORS and FUNCTIONS
+    SECTORS = Cycler(jobs.Sector.objects.all()) 
+    FUNCTIONS = Cycler(jobs.Function.objects.all())
+    
+    obj = jobs.Offer(
+        name="Übersetzer DE-FR (m/w)",
+        remark = """\
+Wir sind auf der Suche nach einem Deutsch-Französich Übersetzer 
+(M/F) um einen Selbständigenr zu Geschäftsessen und kommerziellen 
+Termine zu begleiten. Sie übernehmen die Übersetzung von Gespräche 
+während kommerziellen Kontakte mit deutschen Kunden.
+Es ist spontane und pünktliche Aufträge, den ganzen Tag, in 
+Eupen und/oder Deutschland. 
+Regelmäßigkeit: 1-2 Mal pro Monat, je nach Bedarf. 
+Flexibilität: die Termine sind je nach Kandidat anpassbar.""",
+        provider=PROVIDERS.pop(),
+        selection_from=settings.SITE.demo_date(-120),
+        selection_until=settings.SITE.demo_date(-20),
+        start_date=settings.SITE.demo_date(10),
+        sector=SECTORS.pop(),
+        function=FUNCTIONS.pop())
+    yield obj
+
+    # reset SECTORS and FUNCTIONS
+    SECTORS = Cycler(jobs.Sector.objects.all()) 
+    FUNCTIONS = Cycler(jobs.Function.objects.all())
+    
+    for i in range(30):
+        yield jobs.Candidature(
+          person=CLIENTS.pop(),
+          state=CSTATES.pop(),
+          date_submitted=settings.SITE.demo_date(-20+i*2),
+          sector=SECTORS.pop(),
+          function=FUNCTIONS.pop(),
+          )
+    
+    COUNTRIES = Cycler(countries.Country.objects.all())
+    COMPANIES = Cycler(Company.objects.all())
+    
+    # reset SECTORS and FUNCTIONS
+    SECTORS = Cycler(jobs.Sector.objects.all()) 
+    FUNCTIONS = Cycler(jobs.Function.objects.all())
+    
+    for i in range(30):
+        yield jobs.Experience(
+          person=CLIENTS.pop(),
+          company=COMPANIES.pop(),
+          country=COUNTRIES.pop(),
+          started=settings.SITE.demo_date(-1200+i*2),
+          stopped=settings.SITE.demo_date(-1200+i*2),
+          sector=SECTORS.pop(),
+          function=FUNCTIONS.pop(),
+          )
+    
+          
+          
     
 
     
@@ -985,8 +1116,6 @@ def objects():
         standby = persongroup(u"Standby",ref_name='9',active=False)
         yield standby
     
-    COUNTRIES = Cycler(countries.Country.objects.all())
-    
     for i,p in enumerate(Client.objects.all()):
         if i % 2:
             country = belgium
@@ -1059,7 +1188,7 @@ def objects():
         if i % 10 == 0:
             p.is_obsolete = True
             p.save()
-
+            
     COMPANIES = Cycler(Company.objects.all()[:5])
     NORMAL_CONTRACT_ENDINGS = Cycler(isip.ContractEnding.objects.filter(needs_date_ended=False))
     PREMATURE_CONTRACT_ENDINGS = Cycler(isip.ContractEnding.objects.filter(needs_date_ended=True))
@@ -1088,6 +1217,35 @@ def objects():
                 if ctr.applies_until is None or ctr.applies_until < settings.SITE.demo_date():
                     ctr.ending = NORMAL_CONTRACT_ENDINGS.pop()
         yield ctr
+        
+    """
+    The reception desk opens at 8am. 20 visitors have checked in, half of which 
+    """
                 
+    RECEPTION_CLIENTS = Cycler(reception.Clients.request(user=theresia))
+    REASONS = Cycler(_("Urgent problem"),'',_("Complain"),_("Information"))
+    today = settings.SITE.demo_date()
+    now = datetime.datetime(today.year,today.month,today.day,8,0)
+    for i in range(1,20):
+        obj = RECEPTION_CLIENTS.pop()
+        now += datetime.timedelta(minutes=3*i,seconds=3*i)
+        obj = reception.create_prompt_event(obj,obj,
+            AGENTS.pop(),
+            REASONS.pop(),
+            settings.SITE.site_config.client_guestrole,
+            now)
+        yield obj
+        
+    #~ qs = cal.Guest.objects.filter(role=settings.SITE.site_config.client_guestrole)
+    qs = cal.Guest.objects.filter(waiting_since__isnull=False)
+    for i,obj in enumerate(qs):
+        if i % 2 == 0:
+            obj.busy_since = obj.waiting_since + datetime.timedelta(minutes=2*i,seconds=2*i)
+            obj.state = cal.GuestStates.busy
+            if i % 4 == 0:
+                obj.gone_since = obj.busy_since + datetime.timedelta(minutes=2*i,seconds=3*i)
+                obj.state = cal.GuestStates.gone
+                
+        yield obj
 
 #~ print "20121010 pcsw.fixtures.demo has been imported"
