@@ -13,9 +13,13 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
+.. management_command:: watch_tim
+
 Starts a daemon that 
 watches the specified directory for a file :xfile:`changelog.json` 
 to appear.
+
+
 """
 
 import os
@@ -62,6 +66,8 @@ from lino.utils import mti
 from lino.utils.daemoncommand import DaemonCommand
 
 from lino.utils.ssin import is_valid_ssin
+from lino.mixins.beid import BeIdCardTypes
+
 
 LONG_TIME_AGO = datetime.date(1990,1,1)
 
@@ -201,13 +207,13 @@ def pxs2client(row,person):
     par2client(row,person)    
         
     if row.has_key('CARDTYPE'):
-        #~ row.card_type = pcsw.BeIdCardTypes.items_dict.get(row['CARDTYPE'].strip(),'')
+        #~ row.card_type = BeIdCardTypes.items_dict.get(row['CARDTYPE'].strip(),'')
         #~ from lino.apps.pcsw import models as pcsw
         if row['CARDTYPE'] == 0:
-            #~ person.card_type = pcsw.BeIdCardTypes.blank_item
+            #~ person.card_type = BeIdCardTypes.blank_item
             person.card_type = ''
         else:
-            person.card_type = pcsw.BeIdCardTypes.get_by_value(str(row['CARDTYPE']))
+            person.card_type = BeIdCardTypes.get_by_value(str(row['CARDTYPE']))
             
     if row['IDMUT']:
         checkcc(person,ADR_id(row['IDMUT']),CCTYPE_HEALTH_INSURANCE)
@@ -245,7 +251,7 @@ def country2kw(row,kw):
             try:
                 activity = int(activity)
             except ValueError:
-                dblogger.debug("Ignored invalid value PROF = %r",activity)
+                dblogger.info("Ignored invalid value PROF = %r",activity)
             else:
                 if activity:
                     try:
@@ -344,8 +350,8 @@ def json2py(dct):
             #~ kw[k] = data[n]
 
 
-CONTACT_FIELDS = '''id name street street_no street_box addr2 
-country city zip_code region language email url phone gsm remarks'''.split()
+#~ CONTACT_FIELDS = '''id name street street_no street_box addr1 addr2 
+#~ country city zip_code region language email url phone gsm remarks'''.split()
 
 REQUEST = dd.PseudoRequest("watch_tim")
 
@@ -402,7 +408,7 @@ class Controller:
         dd.pre_ui_delete.send(sender=obj,request=REQUEST)
         #~ changes.log_delete(REQUEST,obj)
         obj.delete()
-        dblogger.debug("%s:%s (%s) : DELETE ok",kw['alias'],kw['id'],dd.obj2str(obj))
+        dblogger.info("%s:%s (%s) : DELETE ok",kw['alias'],kw['id'],dd.obj2str(obj))
         
     #~ def prepare_data(self,data):
         #~ return data
@@ -422,7 +428,7 @@ class Controller:
                 return
             #~ watcher = changes.Watcher(obj,True)
             self.applydata(obj,kw['data'])
-            dblogger.debug("%s:%s (%s) : POST %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
+            dblogger.info("%s:%s (%s) : POST %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
             self.validate_and_save(obj)
             dd.pre_ui_create.send(sender=obj,request=REQUEST)
             #~ changes.log_create(REQUEST,obj)
@@ -430,7 +436,7 @@ class Controller:
             watcher = dd.ChangeWatcher(obj)
             dblogger.info("%s:%s : POST becomes PUT",kw['alias'],kw['id'])
             self.applydata(obj,kw['data'])
-            dblogger.debug("%s:%s (%s) : POST %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
+            dblogger.info("%s:%s (%s) : POST %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
             self.validate_and_save(obj)
             watcher.send_update(REQUEST)
             #~ watcher.log_diff(REQUEST)
@@ -451,12 +457,12 @@ class Controller:
         if self.PUT_special(watcher,**kw):
             return 
         self.applydata(obj,kw['data'])
-        dblogger.debug("%s:%s (%s) : PUT %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
+        dblogger.info("%s:%s (%s) : PUT %s",kw['alias'],kw['id'],dd.obj2str(obj),kw['data'])
         self.validate_and_save(obj)
         watcher.send_update(REQUEST)
         #~ watcher.log_diff(REQUEST)
         #~ obj.save()
-        #~ dblogger.debug("%s:%s : PUT %s",kw['alias'],kw['id'],kw['data'])
+        #~ dblogger.info("%s:%s : PUT %s",kw['alias'],kw['id'],kw['data'])
         
     def PUT_special(self,watcher,**kw):
         pass
@@ -525,6 +531,8 @@ class PAR(Controller):
             if data.has_key('FIRME'):
                 for k,v in name2kw(data['FIRME']).items():
                     setattr(obj,k,v)
+            if data.has_key('NAME2'):
+                setattr(obj,'addr1',data['NAME2'])
             if obj.__class__ is Client:
                 par2client(data,obj)
                 mapper.update(gesdos_id='NB1')
