@@ -322,8 +322,8 @@ def site_setup(site):
     #~ """)
     
     site.modules.households.Households.set_detail_layout(box3="""
-    country region
-    city zip_code:10
+    country region city zip_code:10
+    addr1:40
     street_prefix street:25 street_no street_box
     addr2:40
     activity bank_account1:12 bank_account2:12
