@@ -218,7 +218,7 @@ add('50',_("Errors"),'errors') # there's a ticket, but no usable result. cannot
     
 
 
-class unused_ExecuteRequest(dd.RowAction):
+class unused_ExecuteRequest(dd.Action):
     """
     This defines the "Execute" button on a 
     :class:`CBSSRequest` or
@@ -237,7 +237,8 @@ class unused_ExecuteRequest(dd.RowAction):
             #~ return False
         #~ return super(ExecuteRequest,self).get_row_permission(user,obj)
       
-    def run_from_ui(self,obj,ar,**kw):
+    def run_from_ui(self,ar,**kw):
+        obj = ar.selected_rows[0]
         obj.execute_request(ar)
         if obj.status == RequestStates.failed:
             kw.update(message=obj.debug_messages)
@@ -1826,8 +1827,8 @@ def site_setup(self):
     
     
     
-def setup_main_menu(site,ui,profile,m): pass
-def setup_master_menu(site,ui,profile,m): pass
+#~ def setup_main_menu(site,ui,profile,m): pass
+#~ def setup_master_menu(site,ui,profile,m): pass
   
 #~ def setup_my_menu(site,ui,user,m): 
     #~ if user.profile.cbss_level < UserLevels.user: 
