@@ -236,7 +236,7 @@ class CourseOffer(dd.Model):
     #~ def setup_report(model,rpt):
         #~ rpt.add_action(DirectPrintAction('candidates',_("List of candidates"),'candidates'))
         
-    def get_print_language(self,pm):
+    def get_print_language(self):
         "Used by DirectPrintAction"
         return settings.SITE.DEFAULT_LANGUAGE.django_code
         
@@ -294,7 +294,7 @@ class Course(dd.Model,mixins.Printable):
         #~ rpt.add_action(DirectPrintAction('candidates',_("List of candidates"),'candidates'))
         #~ rpt.add_action(DirectPrintAction('participants',_("List of participants"),'participants'))
         
-    def get_print_language(self,pm):
+    def get_print_language(self):
         "Used by DirectPrintAction"
         return settings.SITE.DEFAULT_LANGUAGE.django_code
         
@@ -391,13 +391,14 @@ class RegisterCandidate(dd.ChangeStateAction):
     required = dict(states=['candidate'])
     help_text = _("Register this candidate for this course.")
 
-    def run_from_ui(self,obj,ar,**kw):
+    def run_from_ui(self,ar,**kw):
+        obj = ar.selected_rows[0]
         assert isinstance(obj,CourseRequest)
         if ar.actor.master is Course and ar.master_instance is not None:
             obj.course = ar.master_instance
         if not obj.course:
             return ar.error(_("Cannot register to unknown course."),alert=True)
-        kw = super(RegisterCandidate,self).run_from_ui(obj,ar,**kw)
+        kw = super(RegisterCandidate,self).run_from_ui(ar,**kw)
         kw.update(refresh_all=True)
         kw.update(message=_("%(person)s has been registered to %(course)s") % dict(
                 person=obj.person,course=obj.course))
@@ -408,11 +409,12 @@ class UnRegisterCandidate(dd.ChangeStateAction):
     required = dict(states=['registered'])
     help_text = _("Unregister this candidate from this course.")
 
-    def run_from_ui(self,obj,ar,**kw):
+    def run_from_ui(self,ar,**kw):
+        obj = ar.selected_rows[0]
         assert isinstance(obj,CourseRequest)
         course = obj.course
         obj.course = None
-        kw = super(UnRegisterCandidate,self).run_from_ui(obj,ar,**kw)
+        kw = super(UnRegisterCandidate,self).run_from_ui(ar,**kw)
         kw.update(refresh_all=True)
         kw.update(message=_("%(person)s has been unregistered from %(course)s") 
             % dict(person=obj.person,course=course))
@@ -738,8 +740,8 @@ def setup_main_menu(site,ui,profile,m):
         m.add_action(PendingCourseRequests)
             
   
-def setup_master_menu(site,ui,profile,m): pass
-def setup_my_menu(site,ui,profile,m): pass
+#~ def setup_master_menu(site,ui,profile,m): pass
+#~ def setup_my_menu(site,ui,profile,m): pass
 def setup_config_menu(site,ui,profile,m):
     m = m.add_menu("courses",MODULE_LABEL)
     m.add_action(CourseContents)
