@@ -13,14 +13,7 @@
 ## along with Lino; if not, see <http://www.gnu.org/licenses/>.
 
 """
-This package contains the **Debt Mediation** module 
-(Schuldnerberatung, Médiation de dettes).
-
-It enables social consultants to create :class:`Budgets`.
-A :class:`Budget` collects financial 
-information like monthly income, monthly expenses and debts 
-of a household or a person, then print out a document which serves 
-as base for the consultation and discussion with debtors.
+The :xfile:`models.py` for :mod:`lino_welfare.modlib.reception`.
 
 """
 
@@ -241,10 +234,10 @@ The total monthly amount available for debts distribution."""))
         else:
             return None
         
-    def get_print_language(self,pm):
+    def get_print_language(self):
         if self.partner:
             return self.partner.language
-        return super(Budget,self).get_print_language(pm)
+        return super(Budget,self).get_print_language()
 
     @property
     def actor1(self):
@@ -418,13 +411,17 @@ The total monthly amount available for debts distribution."""))
                 #~ raise Exception("20130327")
                 return
             sar.setup_from(ar)
+            #~ sar.renderer = settings.SITE.ui.ext_renderer
+            #~ sar.setup_from(ar)
             chunks.append(E.h2(unicode(sar.get_title())))
             #~ chunks.append(ar.ui.table2xhtml(sar))
-            chunks.append(settings.SITE.ui.table2xhtml(sar))
+            chunks.append(sar.table2xhtml())
             #~ raise Exception("20130527")
             
         for grp in self.account_groups():
+            #~ render(self.entries_by_group(grp))
             render(self.entries_by_group(grp))
+            #~ render(self.entries_by_group(grp,**ar.spawn_kw()))
         #~ render(self.BudgetSummary(ar))
         #~ render(self.ResultByBudget(ar))
         #~ render(self.DebtsByBudget(ar))
@@ -807,10 +804,20 @@ class EntriesByType(Entries):
     required = dd.required(user_groups='debts')
   
     @classmethod
-    def class_init(self):
+    def get_known_values(self): # 20130906
+        return dict(account_type=self._account_type)
+        
+    @classmethod
+    def get_actor_label(self): # 20130906
+        if self._account_type is not None:
+            return self._account_type.text
+        return self._label or self.__name__
+        
+    @classmethod
+    def unused_class_init(self):
         super(EntriesByType,self).class_init()
         if self._account_type is not None:
-            self.label = self._account_type.text
+            #~ self.label = self._account_type.text 20130906
             #~ print 20120411, unicode(self.label)
             self.known_values = dict(account_type=self._account_type)
             
@@ -866,10 +873,16 @@ class PrintEntriesByBudget(dd.VirtualTable):
     _account_type = None
     
     @classmethod
-    def class_init(self):
-        super(PrintEntriesByBudget,self).class_init()
+    def get_actor_label(self): # 20130906
         if self._account_type is not None:
-            self.label = self._account_type.text
+            return self._account_type.text
+        return self._label or self.__name__
+        
+    #~ @classmethod
+    #~ def class_init(self):
+        #~ super(PrintEntriesByBudget,self).class_init()
+        #~ if self._account_type is not None:
+            #~ self.label = self._account_type.text
             
     @classmethod
     def get_handle_name(self,ar):
@@ -1271,7 +1284,7 @@ def setup_main_menu(site,ui,profile,m):
     m.add_action(MyBudgets)
   
   
-def setup_master_menu(site,ui,profile,m): pass
+#~ def setup_master_menu(site,ui,profile,m): pass
 
 def unused_setup_my_menu(site,ui,profile,m): 
     m  = m.add_menu("debts",MODULE_LABEL)
