@@ -36,6 +36,201 @@ isip = dd.resolve_app('isip')
 jobs = dd.resolve_app('jobs')
 courses = dd.resolve_app('courses')
 users = dd.resolve_app('users')
+properties = dd.resolve_app('properties')
+
+
+
+#~ class IntegClients(pcsw.Clients):
+class Clients(pcsw.Clients):
+    #~ Black right-pointing triangle : Unicode number: U+25B6  HTML-code: &#9654;
+    #~ Black right-pointing pointer Unicode number: U+25BA HTML-code: &#9658;
+    help_text = u"""Wie Kontakte --> Klienten, aber mit DSBE-spezifischen Kolonnen und Filterparametern."""
+    #~ detail_layout = IntegClientDetail()
+    required = dict(user_groups = 'integ')
+    params_panel_hidden = True
+    title = _("Integration Clients")
+    order_by = "last_name first_name id".split()
+    allow_create = False # see blog/2012/0922
+    use_as_default_table = False
+    column_names = "name_column:20 applies_from applies_until national_id:10 gsm:10 address_column age:10 email phone:10 id bank_account1 aid_type language:10"
+    
+    parameters = dict(
+        group = models.ForeignKey("pcsw.PersonGroup",blank=True,null=True,
+            verbose_name=_("Integration phase")),
+        #~ new_since = models.DateField(_("Coached since"),blank=True,default=amonthago),
+        language = dd.ForeignKey('languages.Language',
+            verbose_name=_("Language knowledge"),
+            blank=True,null=True),
+        wanted_property = dd.ForeignKey(properties.Property,
+            verbose_name=_("Wanted skill"),
+            blank=True,null=True),
+        only_active = models.BooleanField(_("Only active clients"),default=False,
+          help_text=_("Show only clients in 'active' integration phases")),
+        **pcsw.Clients.parameters)
+    #~ params_layout = 'coached_on coached_by group only_active only_primary also_obsolete client_state new_since'
+    #~ params_layout = 'coached_on coached_by group only_active only_primary also_obsolete new_since'
+    params_layout = """
+    client_state coached_by and_coached_by start_date end_date observed_event 
+    aged_from aged_to gender nationality also_obsolete 
+    language wanted_property group only_active only_primary 
+    """
+    
+    #~ @classmethod
+    #~ def get_actor_label(self):
+        #~ return self.model._meta.verbose_name_plural
+    
+    @classmethod
+    def param_defaults(self,ar,**kw):
+        kw = super(Clients,self).param_defaults(ar,**kw)
+        kw.update(client_state=pcsw.ClientStates.coached)
+        kw.update(coached_by=ar.get_user())
+        #~ logger.info("20130923 integ.Clients.param_defaults %s", kw['coached_by'])
+        #~ raise Exception(20130721)
+        return kw
+        
+    @classmethod
+    def get_request_queryset(self,ar):
+        #~ ar.param_values.update(client_state = ClientStates.coached)
+        qs = super(Clients,self).get_request_queryset(ar)
+        if ar.param_values.language:
+            qs = qs.filter(
+                languageknowledge__language=ar.param_values.language).distinct()
+        if ar.param_values.wanted_property:
+            qs = qs.filter(
+                personproperty__property=ar.param_values.wanted_property).distinct()
+                
+        if ar.param_values.group:
+            qs = qs.filter(group=ar.param_values.group)
+        if ar.param_values.only_active:
+            qs = qs.filter(group__active=True)
+        #~ qs = qs.filter(client_state__in=(ClientStates.coached,ClientStates.official))
+        #~ qs = qs.filter(client_state=ClientStates.coached)
+        #~ logger.info('20120914 Clients.get_request_queryset --> %d',qs.count())
+        return qs
+        
+    @classmethod
+    def get_title_tags(self,ar):
+        for t in super(Clients,self).get_title_tags(ar):
+            yield t
+        if ar.param_values.only_active:
+            yield unicode(ar.actor.parameters['only_active'].verbose_name)
+        if ar.param_values.language:
+            yield unicode(ar.actor.parameters['language'].verbose_name) + ' '+unicode(ar.param_values.language)
+        if ar.param_values.group:
+            yield unicode(ar.param_values.group)
+            
+
+
+class UsersWithClients(dd.VirtualTable):
+    """
+    A customized overview table.
+    """
+    #~ debug_permissions = True
+    required = dict(user_groups='integ newcomers')
+    #~ label = _("Overview Clients By User")
+    label = _("Users with their Clients")
+    #~ column_defaults = dict(width=8)
+    
+    slave_grid_format = 'html'    
+    
+    #~ @classmethod
+    #~ def on_analyze(self,site):
+        #~ if self.has_handle(site.ui):
+        #~ raise Exception("20130302 on_analyze called after handle")
+        
+    
+
+    @classmethod
+    def get_data_rows(self,ar):
+        """
+        We only want the users who actually have at least one client.
+        We store the corresponding request in the user object 
+        under the name `my_persons`.
+        
+        The list displays only integration agents, i.e. users with a nonempty `integ_level`.
+        With one subtility: system admins also have a nonempty `integ_level`, 
+        but normal users don't want to see them. 
+        So we add the rule that only system admins see other system admins.
+        
+        """
+        #~ profiles = [p for p in dd.UserProfiles.items() if p.integ_level]
+        u = ar.get_user()
+        if u is None or u.profile.level < dd.UserLevels.admin:
+            profiles = [p for p in dd.UserProfiles.items() 
+                if p.integ_level and p.level < dd.UserLevels.admin]
+        else:
+            profiles = [p for p in dd.UserProfiles.items() if p.integ_level ]
+            #~ qs = qs.exclude(profile__gte=UserLevels.admin)
+                  
+        qs = users.User.objects.filter(profile__in=profiles)
+        for user in qs.order_by('username'):
+            #~ r = MyClients.request(ar.ui,subst_user=user)
+            r = Clients.request(param_values=dict(coached_by=user))
+            if r.get_total_count():
+                user.my_persons = r
+                #~ user._detail_action = users.MySettings.default_action
+                yield user
+                
+    #~ @dd.virtualfield('pcsw.Client.coach1')
+    #~ @dd.virtualfield(dd.ForeignKey(settings.SITE.user_model,verbose_name=_("Coach")))
+    @dd.virtualfield('pcsw.Coaching.user')
+    def user(self,obj,ar):
+        return obj
+        
+    @dd.requestfield(_("Total"))
+    def row_total(self,obj,ar):
+        return obj.my_persons
+        
+    @dd.requestfield(_("Primary clients"))
+    def primary_clients(self,obj,ar):
+        #~ return MyPrimaryClients.request(ar.ui,subst_user=obj)
+        #~ return MyClients.request(ar.ui,subst_user=obj,param_values=dict(only_primary=True))
+        t = datetime.date.today()
+        return Clients.request(param_values=dict(
+            only_primary=True,coached_by=obj,start_date=t,end_date=t))
+        
+    @dd.requestfield(_("Active clients"))
+    def active_clients(self,obj,ar):
+        #~ return MyActiveClients.request(ar.ui,subst_user=obj)
+        t = datetime.date.today()
+        return Clients.request(param_values=dict(
+            only_active=True,coached_by=obj,start_date=t,end_date=t))
+
+#~ @dd.receiver(dd.database_connected)
+#~ def on_database_connected(sender,**kw): 
+@dd.receiver(dd.database_ready)
+def on_database_ready(sender,**kw): 
+    """
+    Builds columns dynamically from the :class:`PersonGroup` database table.
+    
+    This must also be called before each test case.
+    """
+    self = UsersWithClients
+    self.column_names = 'user:10'
+    #~ try:
+    if True:
+        for pg in pcsw.PersonGroup.objects.filter(ref_name__isnull=False).order_by('ref_name'):
+            def w(pg):
+                # we must evaluate `today` for each request, not only once when `database_ready`
+                today = datetime.date.today()
+                def func(self,obj,ar):
+                    return Clients.request(
+                        param_values=dict(group=pg,
+                            coached_by=obj,start_date=today,end_date=today))
+                return func
+            vf = dd.RequestField(w(pg),verbose_name=pg.name)
+            self.add_virtual_field('G'+pg.ref_name,vf)
+            self.column_names += ' ' + vf.name 
+    #~ except DatabaseError as e:
+        #~ pass # happens e.g. if database isn't yet initialized
+        
+    self.column_names += ' primary_clients active_clients row_total'
+    self.clear_handle() # avoid side effects when running multiple test cases
+    settings.SITE.resolve_virtual_fields()
+
+
+
+
 
 
 class CompareRequestsTable(dd.VirtualTable):
@@ -70,7 +265,7 @@ class CompareRequestsTable(dd.VirtualTable):
                 cells.append(ar)
             return cells
             
-        yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.coached)
+        yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.active)
         
         yield add(isip.Contracts,observed_event=isip.ContractEvents.active)
         #~ yield add(isip.Contracts,isip.ContractEvents.ended)
@@ -134,7 +329,7 @@ class PeriodicNumbers(dd.VirtualTable):
         yield add(pcsw.Coachings,observed_event=pcsw.CoachingEvents.active,coaching_type=DSBE)
         yield add(pcsw.Coachings,observed_event=pcsw.CoachingEvents.ended,coaching_type=DSBE)
         
-        yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.coached)
+        yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.active)
         yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.created)
         yield add(pcsw.Clients,observed_event=pcsw.ClientEvents.modified)
         
@@ -354,7 +549,7 @@ class ActivityReport(dd.Report):
     parameters = dict(
       start_date = models.DateField(verbose_name=_("Period from")),
       end_date = models.DateField(verbose_name=_("until")),
-      include_jobs = models.BooleanField(verbose_name=pcsw.JOBS_MODULE_LABEL),
+      include_jobs = models.BooleanField(verbose_name=jobs.App.verbose_name),
       include_isip = models.BooleanField(verbose_name=_("ISIP")),
       )
       
@@ -406,6 +601,58 @@ class ActivityReport(dd.Report):
 
 
 
-def setup_main_menu(site,ui,profile,m): 
-    m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
+#~ def setup_main_menu(site,ui,profile,m): 
+    #~ m  = m.add_menu("integ",pcsw.INTEG_MODULE_LABEL)
+
+
+from lino_welfare.modlib.integ import App
+#~ MODULE_LABEL = App.verbose_name
+
+def setup_reports_menu(site,ui,profile,m):
+    m = m.add_menu("integ",App.verbose_name)
+    #~ m.add_action(site.modules.jobs.OldJobsOverview)
+    m.add_action(site.modules.integ.UsersWithClients)
+    
+    m.add_action(jobs.JobsOverview)
     m.add_action(ActivityReport)
+
+#~ def setup_my_menu(site,ui,profile,m): 
+def setup_main_menu(site,ui,profile,m): 
+    m = m.add_menu("integ",App.verbose_name)
+    m.add_action(Clients)
+    m.add_action(isip.MyContracts)
+    #~ m.add_action(MyPersonSearches)
+    
+    m.add_action(jobs.MyContracts)
+    m.add_action(jobs.JobProviders)
+    m.add_action(jobs.Jobs)
+    m.add_action(jobs.Offers)
+    
+    
+    
+def setup_config_menu(site,ui,profile,m): 
+    m  = m.add_menu("integ",App.verbose_name)
+    m.add_action(isip.ContractTypes)
+    m.add_action(isip.ContractEndings)
+    m.add_action(isip.ExamPolicies)
+    m.add_action(isip.StudyTypes)
+    
+    m.add_action(jobs.ContractTypes)
+    m.add_action(jobs.JobTypes)
+    m.add_action(jobs.Sectors)
+    m.add_action(jobs.Functions)
+    m.add_action(jobs.Schedules)
+    m.add_action(jobs.Regimes)
+    
+  
+def setup_explorer_menu(site,ui,profile,m):
+    m  = m.add_menu("integ",App.verbose_name)
+    m.add_action(isip.Contracts)
+    m.add_action(jobs.Contracts)
+    m.add_action(jobs.Candidatures)
+    m.add_action(jobs.Studies)
+
+    
+
+dd.add_user_group('integ',App.verbose_name)
+#~ dd.add_user_group('coach',INTEG_MODULE_LABEL)
