@@ -56,11 +56,11 @@ from lino.modlib.cal.utils import amonthago
 
 users = dd.resolve_app('users')
 contacts = dd.resolve_app('contacts')
-pcsw = dd.resolve_app('pcsw')
+pcsw = dd.resolve_app('pcsw',strict=True)
 outbox = dd.resolve_app('outbox')
 
-if not hasattr(pcsw,'Clients'):
-    print os.environ['DJANGO_SETTINGS_MODULE']
+#~ if not hasattr(pcsw,'Clients'):
+    #~ print os.environ['DJANGO_SETTINGS_MODULE']
 
 MODULE_LABEL = _("Newcomers")
 
@@ -258,10 +258,10 @@ eines Begleiters oder Ablehnen des Hilfeantrags."""
       also_refused = models.BooleanField(_("Also refused clients"),
           default=False),
       also_obsolete = models.BooleanField(
-          _("Also deprecated clients"),
+          _("Also obsolete records"),
           default=False),
       #~ new_since = models.DateField(_("New clients since"),blank=True),
-      new_since = models.DateField(_("Also newly coached clients since"),
+      new_since = models.DateField(_("New clients since"),
           #~ default=amonthago,
           blank=True,null=True,help_text=u"""\
 Auch Klienten, die erst seit Kurzem begleitet sind."""),
@@ -270,8 +270,16 @@ Auch Klienten, die erst seit Kurzem begleitet sind."""),
           verbose_name=_("Coached by")),
       #~ coached_on = models.DateField(_("Coached on"),blank=True,null=True),
       )
-    params_layout = 'also_refused also_obsolete new_since coached_by'
+    params_layout = 'new_since also_refused also_obsolete coached_by'
     
+    @classmethod
+    def param_defaults(self,ar,**kw):
+        # Note that we skip pcsw.Clients mro parent
+        #~ kw = super(NewClients,self).param_defaults(ar,**kw)
+        kw = super(contacts.Persons,self).param_defaults(ar,**kw)
+        kw.update(new_since=amonthago())
+        return kw
+            
     @classmethod
     def get_request_queryset(self,ar):
         # Note that we skip pcsw.Clients mro parent
@@ -320,9 +328,7 @@ class ClientsByFaculty(pcsw.Clients):
     
         
 class AvailableCoaches(users.Users):
-    """
-    A list of the Users that are susceptible to become responsible for a Newcomer.
-    """
+    help_text = _("List of users available for new coachings")
     use_as_default_table = False
     required = dict(user_groups='newcomers')
     auto_fit_column_widths = True
@@ -436,7 +442,7 @@ class AvailableCoaches(users.Users):
         
     #~ @dd.requestfield(_("Active clients"))
     #~ def active_clients(self,obj,ar):
-        #~ return pcsw.IntegClients.request(param_values=dict(coached_by=obj,only_active=True))
+        #~ return integ.Clients.request(param_values=dict(coached_by=obj,only_active=True))
         
     @dd.requestfield(_("New Clients"))
     def new_clients(self,obj,ar):
@@ -513,10 +519,11 @@ nicht mehr angezeigt."""
         return super(AssignCoach,self).get_action_permission(ar,obj,state)
         #~ return super(AssignCoach,self).get_row_permission(ar,state,ba)
         
-    def run_from_ui(self,obj,ar,**kw):
+    def run_from_ui(self,ar,**kw):
         """
         Assign a coach to a newcomer.
         """
+        obj = ar.selected_rows[0]
         client = ar.master_instance
         watcher = dd.ChangeWatcher(client)
         #~ if not ssin.is_valid_ssin(client.national_id):
@@ -661,7 +668,7 @@ dd.inject_field(pcsw.Client,
     """The Faculty this client has been attributed to.
     """)
 
-def site_setup(site):
+#~ def site_setup(site):
     #~ site.modules.users.Users.add_detail_tab('newcomers.CompetencesByUser')
     #~ site.modules.pcsw.Clients.add_detail_tab('newcomers',"""
     #~ broker:12 faculty:12  
@@ -674,21 +681,21 @@ def site_setup(site):
     #~ newcomers_left newcomers.AvailableCoachesByClient
     #~ """)
     
-    site.modules.pcsw.Clients.detail_layout.coaching.replace('workflow_buttons',"""
-    newcomers_left:20 newcomers.AvailableCoachesByClient:40
-    """)
+    #~ site.modules.pcsw.Clients.detail_layout.coaching.replace('workflow_buttons',"""
+    #~ newcomers_left:20 newcomers.AvailableCoachesByClient:40
+    #~ """)
     
     #~ site.modules.pcsw.Clients.detail_layout.update(newcomers_left="""
     #~ workflow_buttons
     #~ broker:12 
     #~ faculty:12  
     #~ """)
-    site.modules.pcsw.Clients.detail_layout.update(
-        newcomers_left=dd.Panel("""
-        workflow_buttons
-        broker:12 
-        faculty:12  
-        """,required=dict(user_groups='newcomers')))
+    #~ site.modules.pcsw.Clients.detail_layout.update(
+        #~ newcomers_left=dd.Panel("""
+        #~ workflow_buttons
+        #~ broker:12 
+        #~ faculty:12  
+        #~ """,required=dict(user_groups='newcomers')))
     
     #~ coaching = dd.Panel("""
     #~ pcsw.ContactsByClient:40 pcsw.CoachingsByClient:40
@@ -707,12 +714,13 @@ def setup_main_menu(site,ui,profile,m):
     #~ m  = m.add_menu("pcsw",pcsw.MODULE_LABEL)
     #~ m.add_action(Newcomers)
     m.add_action(NewClients)
+    m.add_action(AvailableCoaches)
             
   
-def setup_master_menu(site,ui,profile,m): pass
+#~ def setup_master_menu(site,ui,profile,m): pass
   
-def setup_my_menu(site,ui,profile,m): 
-    pass
+#~ def setup_my_menu(site,ui,profile,m): 
+    #~ pass
     
 def setup_config_menu(site,ui,profile,m): 
     #~ if user.profile.newcomers_level < UserLevels.manager:
@@ -726,9 +734,10 @@ def setup_explorer_menu(site,ui,profile,m):
         #~ return
     m.add_action(Competences)
 
-def setup_reports_menu(site,ui,profile,m):
-    m.add_action(AvailableCoaches)
+#~ def setup_reports_menu(site,ui,profile,m):
+    #~ m  = m.add_menu("newcomers",MODULE_LABEL)
+    #~ m.add_action(AvailableCoaches)
   
 dd.add_user_group('newcomers',MODULE_LABEL)
 
-#~ customize_pcsw()
\ No newline at end of file
+#~ customize_pcsw()
