@@ -24,7 +24,7 @@
 SETUP_INFO = dict(name='lino-welfare',
       #~ distclass=MyDistribution,
       #~ dist_dir=os.path.join('docs','dist'),
-      version='1.1.9', 
+      version='1.1.10', # released 20131007(?)
       install_requires=['lino','suds','vobject'],
       #~ version=VERSION,
       test_suite = 'tests',
@@ -106,8 +106,6 @@ SETUP_INFO.update(packages=[
   'lino_welfare.modlib.pcsw',
   'lino_welfare.modlib.pcsw.fixtures',
   'lino_welfare.modlib.reception',
-  'lino_welfare.modlib.statbel',
-  'lino_welfare.modlib.statbel.fixtures',
 ])
 
 SETUP_INFO.update(message_extractors = {
